@@ -109,6 +109,7 @@ pub struct SerializedConfig<'a> {
     languages: HashMap<&'a String, &'a languages::LanguageOptions>,
     default_language: &'a str,
     generate_feed: bool,
+    generate_feeds: bool,
     feed_filenames: &'a [String],
     taxonomies: &'a [taxonomies::TaxonomyConfig],
     author: &'a Option<String>,
@@ -323,6 +324,7 @@ impl Config {
             languages: self.languages.iter().filter(|(k, _)| k.as_str() != lang).collect(),
             default_language: &self.default_language,
             generate_feed: options.generate_feeds,
+            generate_feeds: options.generate_feeds,
             feed_filenames: &options.feed_filenames,
             taxonomies: &options.taxonomies,
             author: &self.author,
